@@ -7,15 +7,15 @@ describe 'swift::objectexpirer' do
       :enabled                       => true,
       :package_ensure                => 'present',
       :pipeline                      => ['catch_errors', 'proxy-logging', 'cache', 'proxy-server'],
-      :auto_create_account_prefix    => '.',
-      :concurrency                   => 1,
-      :expiring_objects_account_name => 'expiring_objects',
-      :interval                      => 300,
-      :process                       => 0,
-      :processes                     => 0,
-      :reclaim_age                   => 604800,
-      :recon_cache_path              => '/var/cache/swift',
-      :report_interval               => 300,
+      :auto_create_account_prefix    => '<SERVICE DEFAULT>',
+      :concurrency                   => '<SERVICE DEFAULT>',
+      :expiring_objects_account_name => '<SERVICE DEFAULT>',
+      :interval                      => '<SERVICE DEFAULT>',
+      :process                       => '<SERVICE DEFAULT>',
+      :processes                     => '<SERVICE DEFAULT>',
+      :reclaim_age                   => '<SERVICE DEFAULT>',
+      :recon_cache_path              => '<SERVICE DEFAULT>',
+      :report_interval               => '<SERVICE DEFAULT>',
       :log_facility                  => 'LOG_LOCAL2',
       :log_level                     => 'INFO',
       :memcache_servers              => ['127.0.0.1:11211'],
@@ -74,7 +74,7 @@ describe 'swift::objectexpirer' do
       end
     end
 
-    context 'when overridding parameters' do
+    context 'when overriding parameters' do
       before do
         params.merge!(
           :interval    => '600',
@@ -92,8 +92,8 @@ describe 'swift::objectexpirer' do
       end
 
       it 'should not configure memcache servers' do
-        is_expected.to_not contain_swift_object_expirer_config(
-          'filter:cache/memcache_servers')
+        is_expected.to contain_swift_object_expirer_config(
+          'filter:cache/memcache_servers').with_ensure('absent')
       end
     end
 
