@@ -20,7 +20,6 @@ describe 'swift::proxy::ceilometer' do
       it { is_expected.to contain_swift_proxy_config('filter:ceilometer/paste.filter_factory').with_value('ceilometermiddleware.swift:filter_factory') }
       it { is_expected.to contain_swift_proxy_config('filter:ceilometer/url').with_value('rabbit://user_1:user_1_passw@1.1.1.1:5673/rabbit').with_secret(true) }
       it { is_expected.to contain_swift_proxy_config('filter:ceilometer/nonblocking_notify').with_value('false') }
-      it { is_expected.to contain_user('swift').with_groups('ceilometer') }
 
       it { is_expected.to contain_package('python-ceilometermiddleware').with(
         :ensure => 'present',
@@ -31,8 +30,7 @@ describe 'swift::proxy::ceilometer' do
 
     describe "when overriding default parameters with rabbit driver" do
       let :params do
-        { :group                 => 'www-data',
-          :default_transport_url => 'rabbit://user_1:user_1_passw@1.1.1.1:5673/rabbit',
+        { :default_transport_url => 'rabbit://user_1:user_1_passw@1.1.1.1:5673/rabbit',
           :driver                => 'messagingv2',
           :topic                 => 'notifications',
           :control_exchange      => 'swift',
@@ -50,7 +48,6 @@ describe 'swift::proxy::ceilometer' do
       end
 
       context 'with single rabbit host' do
-        it { is_expected.to contain_user('swift').with_groups('www-data') }
         it { is_expected.to contain_swift_proxy_config('filter:ceilometer/paste.filter_factory').with_value('ceilometermiddleware.swift:filter_factory') }
         it { is_expected.to contain_swift_proxy_config('filter:ceilometer/url').with_value('rabbit://user_1:user_1_passw@1.1.1.1:5673/rabbit').with_secret(true) }
         it { is_expected.to contain_swift_proxy_config('filter:ceilometer/driver').with_value('messagingv2') }
@@ -78,12 +75,22 @@ describe 'swift::proxy::ceilometer' do
       end
 
       it { is_expected.to contain_oslo__messaging__rabbit('swift_proxy_config').with(
-        :rabbit_use_ssl     => '<SERVICE DEFAULT>',
-        :kombu_ssl_ca_certs => '<SERVICE DEFAULT>',
-        :kombu_ssl_certfile => '<SERVICE DEFAULT>',
-        :kombu_ssl_keyfile  => '<SERVICE DEFAULT>',
-        :kombu_ssl_version  => '<SERVICE DEFAULT>',
+        :rabbit_ha_queues            => '<SERVICE DEFAULT>',
+        :heartbeat_timeout_threshold => '<SERVICE DEFAULT>',
+        :heartbeat_rate              => '<SERVICE DEFAULT>',
+        :heartbeat_in_pthread        => '<SERVICE DEFAULT>',
+        :rabbit_qos_prefetch_count   => '<SERVICE DEFAULT>',
+        :amqp_durable_queues         => '<SERVICE DEFAULT>',
+        :kombu_ssl_ca_certs          => '<SERVICE DEFAULT>',
+        :kombu_ssl_certfile          => '<SERVICE DEFAULT>',
+        :kombu_ssl_keyfile           => '<SERVICE DEFAULT>',
+        :kombu_ssl_version           => '<SERVICE DEFAULT>',
+        :rabbit_use_ssl              => '<SERVICE DEFAULT>',
+        :kombu_reconnect_delay       => '<SERVICE DEFAULT>',
+        :kombu_failover_strategy     => '<SERVICE DEFAULT>',
+        :kombu_compression           => '<SERVICE DEFAULT>',
       )}
+      it { is_expected.to contain_oslo__messaging__amqp('swift_proxy_config') }
 
       context 'with overridden rabbit ssl params' do
         before do
