@@ -21,11 +21,7 @@ describe 'swift::proxy' do
       end
 
       describe 'without the proxy local network ip address being specified' do
-        if Puppet::Util::Package.versioncmp(Puppet.version, '4.3.0') >= 0
-          it_raises 'a Puppet::Error', /expects a value for parameter 'proxy_local_net_ip'/
-        else
-          it_raises 'a Puppet::Error', /Must pass proxy_local_net_ip/
-        end
+        it_raises 'a Puppet::Error', /expects a value for parameter 'proxy_local_net_ip'/
       end
 
       describe 'when proxy_local_net_ip is set' do
@@ -61,6 +57,7 @@ describe 'swift::proxy' do
         it { should contain_swift_proxy_config('DEFAULT/log_level').with_value('INFO') }
         it { should contain_swift_proxy_config('DEFAULT/log_headers').with_value('False') }
         it { should contain_swift_proxy_config('DEFAULT/log_address').with_value('/dev/log') }
+        it { should contain_swift_proxy_config('DEFAULT/client_timeout').with_value('<SERVICE DEFAULT>') }
         it { should contain_swift_proxy_config('pipeline:main/pipeline').with_value(
           ['catch_errors', 'gatekeeper', 'healthcheck', 'proxy-logging', 'cache',
            'listing_formats', 'tempauth', 'copy', 'proxy-logging', 'proxy-server'].join(' ')) }
@@ -69,13 +66,17 @@ describe 'swift::proxy' do
         it { should contain_swift_proxy_config('app:proxy-server/set log_facility').with_value('LOG_LOCAL2') }
         it { should contain_swift_proxy_config('app:proxy-server/set log_level').with_value('INFO') }
         it { should contain_swift_proxy_config('app:proxy-server/set log_address').with_value('/dev/log') }
-        it { should contain_swift_proxy_config('app:proxy-server/log_handoffs').with_value('true') }
-        it { should contain_swift_proxy_config('app:proxy-server/object_chunk_size').with_value('65536') }
-        it { should contain_swift_proxy_config('app:proxy-server/client_chunk_size').with_value('65536') }
+        it { should contain_swift_proxy_config('app:proxy-server/log_handoffs').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('app:proxy-server/object_chunk_size').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('app:proxy-server/client_chunk_size').with_value('<SERVICE DEFAULT>') }
         it { should contain_swift_proxy_config('app:proxy-server/allow_account_management').with_value('true') }
         it { should contain_swift_proxy_config('app:proxy-server/account_autocreate').with_value('true') }
-        it { should contain_swift_proxy_config('app:proxy-server/max_containers_per_account').with_value(0) }
+        it { should contain_swift_proxy_config('app:proxy-server/max_containers_per_account').with_value('<SERVICE DEFAULT>') }
         it { should contain_swift_proxy_config('app:proxy-server/max_containers_whitelist').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('app:proxy-server/write_affinity').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('app:proxy-server/write_affinity_node_count').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('app:proxy-server/node_timeout').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('app:proxy-server/recoverable_node_timeout').with_value('<SERVICE DEFAULT>') }
 
         it { should contain_service('swift-proxy-server').with_require([
           'Class[Swift::Proxy::Catch_errors]',
@@ -158,7 +159,7 @@ describe 'swift::proxy' do
           it { should contain_swift_proxy_config('app:proxy-server/set log_facility').with_value('LOG_LOCAL2') }
           it { should contain_swift_proxy_config('app:proxy-server/set log_level').with_value('DEBUG') }
           it { should contain_swift_proxy_config('app:proxy-server/set log_address').with_value('/dev/log') }
-          it { should contain_swift_proxy_config('app:proxy-server/log_handoffs').with_value('true') }
+          it { should contain_swift_proxy_config('app:proxy-server/log_handoffs').with_value('<SERVICE DEFAULT>') }
           it { should contain_swift_proxy_config('app:proxy-server/object_chunk_size').with_value('8192') }
           it { should contain_swift_proxy_config('app:proxy-server/client_chunk_size').with_value('8192') }
           it { should contain_swift_proxy_config('app:proxy-server/allow_account_management').with_value('false') }
@@ -211,6 +212,7 @@ describe 'swift::proxy' do
                 :log_name                  => 'swift-proxy-server',
                 :log_udp_host              => '127.0.0.1',
                 :log_udp_port              => '514',
+                :log_handoffs              => true,
                 :read_affinity             => 'r1z1=100, r1=200',
                 :write_affinity            => 'r1',
                 :write_affinity_node_count => '2 * replicas',
