@@ -19,18 +19,14 @@ describe 'swift::storage::all' do
       :outgoing_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
       :log_requests    => true,
       :max_connections => 25,
-      :rsync_timeout   => 900,
-      :rsync_bwlimit   => 0
+      :rsync_timeout   => '<SERVICE DEFAULT>',
+      :rsync_bwlimit   => '<SERVICE DEFAULT>'
     }
   end
 
   shared_examples 'swift::storage::all' do
     describe 'when an internal network ip is not specified' do
-      if Puppet::Util::Package.versioncmp(Puppet.version, '4.3.0') >= 0
-        it_raises 'a Puppet::Error', /expects a value for parameter 'storage_local_net_ip'/
-      else
-        it_raises 'a Puppet::Error', /Must pass storage_local_net_ip/
-      end
+      it_raises 'a Puppet::Error', /expects a value for parameter 'storage_local_net_ip'/
     end
 
     [{ :storage_local_net_ip => '127.0.0.1' },
@@ -40,9 +36,9 @@ describe 'swift::storage::all' do
        :object_port          => "7000",
        :container_port       => "7001",
        :account_port         => "7002",
-       :object_pipeline      => ["healthcheck"],
-       :container_pipeline   => ["healthcheck"],
-       :account_pipeline     => ["healthcheck"],
+       :object_pipeline      => ['healthcheck', 'object-server'],
+       :container_pipeline   => ['healthcheck', 'container-server'],
+       :account_pipeline     => ['healthcheck', 'account-server'],
        :splice               => true,
        :log_facility         => ['LOG_LOCAL2', 'LOG_LOCAL3'],
        :incoming_chmod       => '0644',
@@ -125,55 +121,6 @@ describe 'swift::storage::all' do
         )}
       end
     end
-
-    describe "when specifying statsd enabled" do
-      let :params do
-        {
-          :storage_local_net_ip           => '127.0.0.1',
-          :statsd_enabled                 => true,
-          :log_statsd_host                => 'statsd.example.com',
-          :log_statsd_port                => '9999',
-          :log_statsd_default_sample_rate => '2.0',
-          :log_statsd_sample_rate_factor  => '1.5',
-          :log_statsd_metric_prefix       => 'foo',
-        }
-      end
-
-      {'object' => '6000', 'container' => '6001', 'account' => '6002'}.each do |type,name|
-        it "should configure statsd in the #{type} config file" do
-         is_expected.to contain_concat_fragment("swift-#{type}-#{name}").with_content(
-           /log_statsd_host = statsd.example.com/
-         ).with_content(
-           /log_statsd_port = 9999/
-         ).with_content(
-           /log_statsd_default_sample_rate = 2.0/
-         ).with_content(
-           /log_statsd_sample_rate_factor = 1.5/
-         ).with_content(
-           /log_statsd_metric_prefix = foo/
-         )
-        end
-      end
-    end
-
-    describe "when specifying number of workers" do
-      let :params do
-        {
-          :storage_local_net_ip	    => '127.0.0.1',
-          :account_server_workers     => '42',
-          :container_server_workers   => '42',
-          :object_server_workers      => '42',
-        }
-      end
-
-      {'object' => '6000', 'container' => '6001', 'account' => '6002'}.each do |type,name|
-        it "should define worker count in the #{type} config file" do
-         is_expected.to contain_concat_fragment("swift-#{type}-#{name}").with_content(
-           /workers = 42/
-         )
-        end
-      end
-    end
   end
 
   shared_examples 'swift::storage::all debian' do
